/***************************************************************************
                               ChatOptionsImp.h
                             -------------------
    begin                : Tuesday Nov 14 2000
    copyright            : (C) 2000 Benjamin Meyer 
    email                : benjamin@csh.rit.edu
 ***************************************************************************/

#ifndef CHATOPTIONSIMP_H
#define CHATOPTIONSIMP_H

#include <chatoptions.h>
class QFont;
class QLabel;

/**
  *@author Benjamin Meyer
  */

class ChatOptionsImp : public ChatOptions  {

Q_OBJECT
	
public:
  ChatOptionsImp(QWidget *parent=0, const char *name=0);

public slots:
  void updateData();
  void getData();

private slots:
  void changeUserFont();
  void changeBuddyFont();
  void setDefaultUserFont();
  void setDefaultBuddyFont();

private:
  void updateFontSetting(QFont &f, QLabel *l);
  void updateLabel( QLabel *l, const QFont &f );
  QFont chat_yourFont;
  QFont chat_contactFont;

};

#endif

// ChatOptionsImp.h

